@@ -13,7 +13,9 @@
 #include "in.h"
 
 #if !SCANLOGD_PROMISC
-#warning "SCANLOGD_PROMISC is 0, but current libnids will set PROMISC anyway"
+#if !(defined(NIDS_MAJOR) && (NIDS_MAJOR > 1 || NIDS_MINOR >= 14))
+#warning "SCANLOGD_PROMISC is 0, but your libnids will set PROMISC anyway"
+#endif
 #endif
 
 static void (*scanlogd_process_packet)(struct header *packet, int size);
@@ -40,11 +42,18 @@ int in_init(void)
 	nids_params.device = SCANLOGD_DEVICE;
 #endif
 
+#if defined(NIDS_MAJOR) && (NIDS_MAJOR > 1 || NIDS_MINOR >= 14)
+	nids_params.n_tcp_streams = 0;
+#else
 	nids_params.n_tcp_streams = 1;
+#endif
 	nids_params.n_hosts = HASH_SIZE;
 	nids_params.syslog = dummy_syslog;
 	nids_params.scan_num_hosts = 0;
 	nids_params.pcap_filter = "tcp";
+#if defined(NIDS_MAJOR) && (NIDS_MAJOR > 1 || NIDS_MINOR >= 14)
+	nids_params.promisc = SCANLOGD_PROMISC;
+#endif
 
 	if (!nids_init()) {
 		fprintf(stderr, "nids_init: %s\n", nids_errbuf);
